@@ -192,7 +192,7 @@ def starred(db_path, username, auth, load):
 @click.option(
     "-a",
     "--auth",
-    type=click.Path(file_okay=True, dir_okay=False, allow_dash=True, exists=True),
+    type=click.Path(file_okay=True, dir_okay=False, allow_dash=True),
     default="auth.json",
     help="Path to auth.json token file",
 )
@@ -244,7 +244,7 @@ def stargazers(db_path, repos, auth):
     help="Fetch HTML rendered README into 'readme_html' column",
 )
 def repos(db_path, usernames, auth, repo, load, readme, readme_html):
-    "Save repos owened by the specified (or authenticated) username or organization"
+    "Save repos owned by the specified (or authenticated) username or organization"
     db = sqlite_utils.Database(db_path)
     token = load_token(auth)
     if load:
@@ -539,7 +539,7 @@ def emojis(db_path, auth, fetch):
     help="Accept header to send, e.g. application/vnd.github.VERSION.html",
 )
 def get(url, auth, paginate, nl, accept):
-    "Save repos owened by the specified (or authenticated) username or organization"
+    "Make an authenticated HTTP GET against the specified URL"
     token = load_token(auth)
     first = True
     should_output_closing_brace = not nl
@@ -585,7 +585,7 @@ def get(url, auth, paginate, nl, accept):
 @click.option(
     "-a",
     "--auth",
-    type=click.Path(file_okay=True, dir_okay=False, allow_dash=True, exists=True),
+    type=click.Path(file_okay=True, dir_okay=False, allow_dash=True),
     default="auth.json",
     help="Path to auth.json token file",
 )
